@@ -540,7 +540,7 @@ class FriendlyTraceback:
         self.locate_exception_raised(records[-1])
         self.info["detailed_tb"] = self.get_detailed_stack_info(records)
         if len(records) > 1:
-            _ignore, partial_source, var_info = self.info["detailed_tb"][-1]
+            _ignore, partial_source, var_info = self.info["detailed_tb"][0]
             self.locate_last_call(records[0], partial_source, var_info)
 
     def locate_exception_raised(self, record: FrameInfo) -> None:
@@ -581,7 +581,13 @@ class FriendlyTraceback:
         if unavailable:
             return
 
-        self.info["exception_raised_source"] = partial_source["source"]
+        source = partial_source["source"]
+        if source.strip() in ["-->1:", "1:"]:
+            source = _(
+                "{filename} is not a regular Python file whose contents can be analyzed.\n"
+            ).format(filename=filename)
+
+        self.info["exception_raised_source"] = source
 
         if self.tb_data.node_text:
             line = self.tb_data.node_text
