@@ -115,13 +115,14 @@ class FrameInfo(stack_data.FrameInfo):
         line_gap_mark = "      (...)"
         # fmt: on
 
+        def indent(begin):
+            return " " * (8 + nb_digits + begin + 1)
+
         text_range_mark = None
         if with_node_range and self.node_info:
             if self.node_info[1]:
                 begin, end = self.node_info[1]
-                text_range_mark = " " * (8 + nb_digits + begin + 1) + "^" * (
-                    end - begin
-                )
+                text_range_mark = indent(begin) + "^" * (end - begin)
             elif self.node_info[2] and isinstance(self.node_info[2], str):
                 text = self.node_info[2]
                 for line_obj in lines:
@@ -130,9 +131,7 @@ class FrameInfo(stack_data.FrameInfo):
                     if line_obj.is_current:
                         begin = line_obj.text.find(text)
                         if begin >= 0:
-                            text_range_mark = " " * (
-                                8 + nb_digits + begin + 1
-                            ) + "^" * len(text)
+                            text_range_mark = indent(begin) + "^" * len(text)
 
         marked = False
         prev_lineno = None
@@ -140,35 +139,77 @@ class FrameInfo(stack_data.FrameInfo):
         # this might not be helpful for beginners who look at the code
         # without paying too much attention at the line numbers.
         # I fixed this below.
+        indentations = []
         for line_obj in lines:
             if line_obj is stack_data.LINE_GAP:
                 new_lines.append(line_gap_mark)
                 prev_lineno = None
                 continue
-            if prev_lineno and line_obj.lineno - prev_lineno == 2:
-                # add single empty line
-                num = no_mark.format(prev_lineno + 1)
-                new_lines.append(num)
-            if prev_lineno and line_obj.lineno - prev_lineno > 2:
-                # add line gap to indicate that some empty lines were skipped
-                new_lines.append(line_gap_mark)
+
+            if prev_lineno:
+                if line_obj.lineno - prev_lineno == 2:
+                    # add single empty line
+                    num = no_mark.format(prev_lineno + 1)
+                    new_lines.append(num)
+                elif line_obj.lineno - prev_lineno > 2:
+                    # add line gap to indicate that some empty lines were skipped
+                    new_lines.append(line_gap_mark)
+
             if line_obj.is_current:
                 num = with_mark.format(line_obj.lineno)
                 problem_line = line_obj.text
                 new_lines.append(num + problem_line.rstrip())
                 if text_range_mark is not None:
                     new_lines.append(text_range_mark)
+                    indentations.append(text_range_mark.count(" "))
+                elif self.node_info:
+                    try:
+                        for line_range in line_obj.executing_node_ranges:
+                            begin = line_range.start
+                            end = line_range.end
+                            text_range_mark = indent(begin) + "^" * (end - begin)
+                            new_lines.append(text_range_mark)
+                            indentations.append(text_range_mark.count(" "))
+                    except Exception:
+                        pass
                 marked = True
             elif marked:
-                if not line_obj.text.strip():  # do not add empty line if last line
-                    break
                 num = no_mark.format(line_obj.lineno)
                 new_lines.append(num + line_obj.text.rstrip())
+                for line_range in line_obj.executing_node_ranges:
+                    begin = len(line_obj.text) - len(line_obj.text.lstrip())
+                    end = line_range.end
+                    text_range_mark = indent(begin) + "^" * (end - begin)
+                    new_lines.append(text_range_mark)
+                    indentations.append(text_range_mark.count(" "))
             else:
                 num = no_mark.format(line_obj.lineno)
                 new_lines.append(num + line_obj.text.rstrip())
             prev_lineno = line_obj.lineno
 
+        def re_indent(new_lines, indentations):
+            """Reindent the marked lines so that they are aligned as a block
+            except perhaps for the first line."""
+            min_indent = min(indentations)
+            indentations.pop(0)
+            skipped_first = False
+            re_indented_lines = []
+            for line in new_lines:
+                if set(line).issubset({" ", "^"}) and skipped_first:
+                    current_indent = line.count(" ")
+                    line = (
+                        " " * min_indent
+                        + "^" * (current_indent - min_indent)
+                        + line.lstrip()
+                    )
+                elif set(line).issubset({" ", "^"}):
+                    skipped_first = True
+                re_indented_lines.append(line)
+            return re_indented_lines
+
+        if len(indentations) > 1:
+            new_lines = re_indent(new_lines, indentations)
+
         return "\n".join(new_lines), problem_line
 
     @cached_property
@@ -208,9 +249,11 @@ class FrameInfo(stack_data.FrameInfo):
             if not node_text:
                 # Highlight the entire line
                 try:
+                    tokens = token_utils.tokenize(self.current_line.text)
+                    tokens = token_utils.remove_meaningless_tokens(tokens)
                     return (
                         None,
-                        (0, len(self.current_line.text)),
+                        (tokens[0].start_col, tokens[-1].end_col),
                         self.current_line.text,
                     )
                 except Exception:
